#!/usr/bin/env python3
import random
import re
from functools import partial

EMOJI_LUT = [
    "rawr x3",
    "OwO",
    "UwU",
    "o.O",
    "-.-",
    ">w<",
    "(⑅˘꒳˘)",
    "(ꈍᴗꈍ)",
    "(˘ω˘)",
    "(U ᵕ U❁)",
    "σωσ",
    "òωó",
    "(///ˬ///✿)",
    "(U ﹏ U)",
    "( ͡o ω ͡o )",
    "ʘwʘ",
    ":3",
    ":3", # important enough to have twie
    "XD",
    "nyaa~~",
    "mya",
    ">_<",
    "😳",
    "🥺",
    "😳😳😳",
    "rawr",
    "^^",
    "^^;;",
    "(ˆ ﻌ ˆ)♡",
    "^•ﻌ•^",
    "/(^•ω•^)",
    "(✿oωo)",
]

punctuation_regex = re.compile(r"[\.!\?;\s]+")

def emoji(strength: float, input_string: str):
        return punctuation_regex.sub(partial(replace, strength=strength), input_string, 0)


def replace(match, strength = 0.0):
    match_string = match.string[slice(*match.span())]
    if random.random() < strength:
        return f"{match_string} " + EMOJI_LUT[random.randint(0, len(EMOJI_LUT) - 1)] + " "

    return match_string


#!/usr/bin/env python3
from .wepwace import word_replace ,char_replace
from .nya import nyaify
from .stutter import stutter
from .emoji import emoji

class UwU:
    @staticmethod
    def ify(input_string: str, *, stutter_strength: float = 0.2, emoji_strength: float = 0.2) -> str:
        input_string = input_string.lower()
        input_string = word_replace(input_string) # replacification DONE!
        input_string = nyaify(input_string) # nyaification is done!
        input_string = char_replace(input_string) # wepwacement is done!
        input_string = stutter(stutter_strength, input_string) # after lots of toil, stuttering is d-done...
        input_string = emoji(emoji_strength, input_string) # emojis done
        return input_string



#!/usr/bin/env python3
import random
import re
from functools import partial

uwugex = re.compile(r"(\s)([a-zA-Z])")
subst = "\\g<1>\\g<2>-\\g<2>"

def stutter(strength: float, input_string: str):
        return uwugex.sub(partial(replace, strength=strength), input_string, 0)

def replace(match, strength = 0.0):
    match_string = match.string[slice(*match.span())]
    if random.random() < strength:
        char = match_string[-1]
        return f"{match_string}-{char}"
    return match_string


#!/usr/bin/env python3
import re

WORD_HASH = {
    "small": "smol",
    "cute": "kawaii~",
    "fluff": "floof",
    "love": "luv",
    "stupid": "baka",
    "idiot": "baka",
    "what": "nani",
    "meow": "nya~",
    "roar": "rawrr~",
}

uwugex = re.compile(r"(?<![wrl])[lr](?![wrl])") # Laundmo certified UwUgex

def word_replace(input_string: str) -> str:
    for word in WORD_HASH: # Python sucks because Verboof doesn't let me do what I want :c
        input_string = input_string.replace(word, WORD_HASH[word])

    return input_string

def char_replace(input_string: str) -> str:
    return uwugex.sub("w", input_string)




#!/usr/bin/env python3
import re

uwugex = re.compile(r"n([aeou])([^aeiou])")# TODO: look into regex
substitute = "ny\\g<1>\\g<2>"

def nyaify(input_string):
    return uwugex.sub(substitute, input_string, 0)



#!/usr/bin/env python3
from setuptools import find_packages, setup

setup(
    name='slowo',
    version='0.1',
    description='A python implentación of advanced uwuification.',
    license="GPLv3",
    author='Gintautas Kazlauskas',
    author_email='gintautaskazlauskas@protonmail.com',
    url="https://www.github.com/gitautas/slowo",
    package_dir = {
        "": "src"
    },
    packages=["slowo"],  #same as name
    install_requires=['wheel'], #external packages as dependencies
    scripts=[]
)
